Improve this Doc

# `ngResource`

## Installation

First, get the file:

- Google CDN e.g.

      "//ajax.googleapis.com/ajax/libs/angularjs/X.Y.Z/angular-resource.js"

- NPM e.g.

      npm install --save angular-resource@X.Y.Z

  or

      yarn add angular-resource@X.Y.Z

- Bower e.g.

      bower install angular-resource#X.Y.Z

- code.angularjs.org (discouraged for production use) e.g.

      "//code.angularjs.org/X.Y.Z/angular-resource.js"

where X.Y.Z is the AngularJS version you are running.

Then, include `angular-resource.js` in your HTML:

    <script src="path/to/angular.js"></script>
    <script src="path/to/angular-resource.js"></script>

Finally, load the module in your application by adding it as a dependent module:

    angular.module('app', ['ngResource']);

With that you're ready to get started!

# ngResource

The `ngResource` module provides interaction support with RESTful services via the $resource service.

See `$resourceProvider` and `$resource` for usage.

## Module Components

### Provider

Name | Description
--- | ---
$resourceProvider | Use `$resourceProvider` to change the default behavior of the `$resource` service.

### Service

Name | Description
--- | ---
$resource | A factory which creates a resource object that lets you interact with RESTful server-side data sources.